@@ -3,11 +3,12 @@ __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint',
 from expressmoney.api import *
 
 
-SERVICE_NAME = 'profiles'
+SERVICE = 'profiles'
 
 
 class UserProfileCreateContract(Contract):
     user_id = serializers.IntegerField(min_value=1)
+    department = serializers.IntegerField(min_value=1)
     ip = serializers.IPAddressField(protocol='ipv4')
     http_referer = serializers.URLField()
 
@@ -52,7 +53,7 @@ class ProfileCreateContract(ProfileUpdateContract):
     # Government ID
     government_id_type = serializers.ChoiceField(choices=GOVERNMENT_ID_TYPE_CHOICES, default=NONE)
     government_id_number = serializers.CharField(max_length=16, allow_blank=True)
-    government_id_date = serializers.DateField(allow_null=True, allow_blank=True)
+    government_id_date = serializers.DateField(allow_null=True, required=False)
 
 
 class ProfileReadContract(ProfileCreateContract):
@@ -77,7 +78,7 @@ class RussianProfileCreateContract(ProfileCreateContract):
     passport_issue_name = serializers.CharField(max_length=256, allow_blank=True)
     passport_code = serializers.CharField(max_length=16)
     passport_date = serializers.DateField()
-    income = serializers.IntegerField(allow_null=True)
+    income = serializers.IntegerField(allow_null=True, required=False)
 
 
 class RussianProfileReadContract(ProfileReadContract,):
@@ -92,26 +93,34 @@ class RussianProfileReadContract(ProfileReadContract,):
     fias_region = serializers.CharField(max_length=256, allow_blank=True)
 
 
-profiles_profiles_russian_profile = ID(SERVICE_NAME, 'profiles', 'russian_profile')
-profiles_profiles_user_profile = ID(SERVICE_NAME, 'profiles', 'user_profile')
+class RussianProfileID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'russian_profile'
+
+
+class UserProfileID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'user_profile'
 
 
 class UserProfilePoint(CreatePointMixin, ContractPoint):
-    _point_id = profiles_profiles_user_profile
+    _point_id = UserProfileID()
     _create_contract = UserProfileCreateContract
 
 
 class UserProfileObjectPoint(UpdatePointMixin, ContractObjectPoint):
-    _point_id = profiles_profiles_user_profile
+    _point_id = UserProfileID()
     _update_contract = UserProfileUpdateContract
 
 
 class RussianProfilePoint(CreatePointMixin, ContractPoint):
-    _point_id = profiles_profiles_russian_profile
+    _point_id = RussianProfileID()
     _create_contract = RussianProfileCreateContract
 
 
 class RussianProfileObjectPoint(RetrievePointMixin, UpdatePointMixin, ContractObjectPoint):
-    _point_id = profiles_profiles_russian_profile
+    _point_id = RussianProfileID()
     _read_contract = RussianProfileReadContract
     _update_contract = RussianProfileUpdateContract
